@@ -13,11 +13,13 @@ def deal(code):
     formatter = HtmlFormatter(linenos=False)
     return highlight(code, lexer, formatter)
 
-def highlight_txt(txt):   
-    return extract_map('<code', '</code>', txt, deal)
+def highlight_txt(txt, tag='code'):
+    tag_pre = '<%s' % tag
+    tag_post = '</%s>' % tag
+    return extract_map(tag_pre, tag_post, txt, deal)
 
 if __name__ == '__main__':
-    code ='''
+    code = '''
 首先是extract：
 <code py>
 #coding:utf-8
